@@ -1,4 +1,52 @@
 
+=head1 NAME
+
+Blog::Spam::Plugin::lotsaurls - Reject comments containing multiple URLs.
+
+=cut
+
+=head1 ABOUT
+
+This plugin is designed to discard comments which contain a significant
+number of URLs.
+
+By default 10 URLs is the threshold, but this may be changed by the
+submitter via the optional parameters submitted to the server - see
+http://api.blogspam.net for details of those parameters.
+
+
+All URLS are detected via the L<URI::Find> module.
+
+=cut
+
+
+=head1 LICENSE
+
+This code is licensed under the terms of the GNU General Public
+License, version 2.  See included file GPL-2 for details.
+
+=cut
+
+=head1 AUTHOR
+
+Steve
+--
+http://www.steve.org.uk/
+
+=cut
+
+=head1 LICENSE
+
+Copyright (c) 2008-2010 by Steve Kemp.  All rights reserved.
+
+This module is free software;
+you can redistribute it and/or modify it under
+the same terms as Perl itself.
+The LICENSE file contains the full text of the license.
+
+=cut
+
+
 
 package Blog::Spam::Plugin::lotsaurls;
 
@@ -32,6 +80,15 @@ sub new
     return $self;
 }
 
+
+=begin doc
+
+Return the name of this plugin.
+
+=end doc
+
+=cut
+
 sub name
 {
     my ($self) = (@_);
